@@ -1,14 +1,15 @@
 package Perinci::Sub::Wrapper::Patch::HandlePHPArray;
 
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use parent qw(Module::Patch);
 
-our $VERSION = '0.02'; # VERSION
-
 my $code = sub {
     my $ctx = shift;
 
@@ -59,7 +60,7 @@ Perinci::Sub::Wrapper::Patch::HandlePHPArray - Convert {} to [] or vice versa to
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Perinci::Sub::Wrapper::Patch::HandlePHPArray (from Perl distribution Perinci-Sub-Wrapper-Patch-HandlePHPArray), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -86,7 +87,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Wrapper-Patch-HandlePHPArray>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Wrapper-Patch-HandlePHPArray>.
 
 =head1 BUGS
 
@@ -98,11 +99,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
